Finalizer typedef
A function that can be used to process the result of a variable expression before it is output.
For example one can convert null implicitly into an empty string here.
Implementation
typedef Finalizer = Object? Function(Object? value);