TemplateAssertionError class
Like a TemplateSyntaxError, but covers cases where something in the template caused an error at parsing time that wasn't necessarily caused by a syntax error.
- Inheritance
-
- Object
- TemplateError
- TemplateSyntaxError
- TemplateAssertionError
Constructors
- TemplateAssertionError(String? message, {String? path, int? line})
- Creates a new TemplateAssertionError.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- line → int?
-
The line in the template that caused the error.
finalinherited
- message → String?
-
The error message.
finalinherited
- path → String?
-
The path to the template that caused the error.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited